CREATE TABLE Language (
Id_Language				TEXT 		PRIMARY KEY,
Name 					TEXT		NOT NULL,
Default_Language		INTEGER		NOT NULL,
Active 					INTEGER		NOT NULL
);

CREATE TABLE Level (
Id_Level				INTEGER 	PRIMARY KEY,
Name 					TEXT		NOT NULL,
UNIQUE(Name)
);

CREATE TABLE LevelLabel (
Id_Level				INTEGER,
Id_Language 			TEXT,
Description 			TEXT,
PRIMARY KEY (Id_Level, Id_Language),
FOREIGN KEY(Id_Level) REFERENCES Level(Id_Level),
FOREIGN KEY(Id_Language) REFERENCES Language(Id_Language)
);

CREATE TABLE Category (
Id_Category				INTEGER 	PRIMARY KEY,
Name					TEXT		NOT NULL,
Order_Category			INTEGER		NOT NULL,
Display_Color			TEXT,
UNIQUE(Name),
UNIQUE(Order_Category)
);

CREATE TABLE CategoryLabel (
Id_Category				INTEGER ,
Id_Language				TEXT,
Title	 				TEXT 		NOT NULL,
Button_Title 			TEXT,
PRIMARY KEY (Id_Category, Id_Language),
FOREIGN KEY(Id_Category) REFERENCES Category(Id_Category),
FOREIGN KEY(Id_Language) REFERENCES Language(Id_Language)
);

CREATE TABLE Topic (
Id_Topic				INTEGER 	PRIMARY KEY,
Name					TEXT		NOT NULL,
Id_Category				INTEGER,
Order_Topic				INTEGER		NOT NULL,
FOREIGN KEY(Id_Category) REFERENCES Category(Id_Category),
UNIQUE(Name),
UNIQUE(Id_Category, Order_Topic)
);

CREATE TABLE TopicLabel (
Id_Topic				INTEGER ,
Id_Language				TEXT,
Title	 				TEXT 		NOT NULL,
Button_Title 			TEXT,
PRIMARY KEY (Id_Topic, Id_Language),
FOREIGN KEY(Id_Topic) REFERENCES Topic(Id_Topic),
FOREIGN KEY(Id_Language) REFERENCES Language(Id_Language)
);

CREATE TABLE TopicTag (
Id_Topic				INTEGER,
Tag 					TEXT,
PRIMARY KEY (Id_Topic, Tag),
FOREIGN KEY(Id_Topic) REFERENCES Topic(Id_Topic)
);

CREATE INDEX topictag_tag on TopicTag(Tag);

CREATE TABLE TopicLocalizedTag (
Id_Topic				INTEGER,
Id_Language				TEXT,
Tag 					TEXT,
PRIMARY KEY (Id_Topic, Id_Language, Tag),
FOREIGN KEY(Id_Topic) REFERENCES Topic(Id_Topic),
FOREIGN KEY(Id_Language) REFERENCES Language(Id_Language)
);

CREATE INDEX topicloctag_tag on TopicLocalizedTag(Tag);

CREATE TABLE Lesson (
Id_Lesson				INTEGER 	PRIMARY KEY,
Id_Topic				INTEGER 	NOT NULL,
Id_Level				INTEGER 	NOT NULL,
Order_Lesson			INTEGER		NOT NULL,
Id_Lesson_Prerequisite	INTEGER,
Paid_Content			INTEGER		NOT NULL,
UNIQUE(Id_Topic, Order_Lesson),
FOREIGN KEY(Id_Topic) REFERENCES Topic(Id_Topic),
FOREIGN KEY(Id_Level) REFERENCES Level(Id_Level)
);

CREATE TABLE LessonLabel (
Id_Lesson				INTEGER,
Id_Language				TEXT,
Title	 				TEXT 		NOT NULL,
Button_Title 			TEXT,
PRIMARY KEY (Id_Lesson, Id_Language),
FOREIGN KEY(Id_Lesson) REFERENCES Lesson(Id_Lesson),
FOREIGN KEY(Id_Language) REFERENCES Language(Id_Language)
);

CREATE TABLE LessonTag (
Id_Lesson				INTEGER,
Tag 					TEXT,
PRIMARY KEY (Id_Lesson, Tag),
FOREIGN KEY(Id_Lesson) REFERENCES Lesson(Id_Lesson)
);

CREATE INDEX lessontag_tag on LessonTag(Tag);

CREATE TABLE LessonLocalizedTag (
Id_Lesson				INTEGER,
Id_Language				TEXT,
Tag 					TEXT,
PRIMARY KEY (Id_Lesson, Id_Language, Tag),
FOREIGN KEY(Id_Lesson) REFERENCES Lesson(Id_Lesson),
FOREIGN KEY(Id_Language) REFERENCES Language(Id_Language)
);

CREATE INDEX lessonloctag_tag on LessonLocalizedTag(Tag);

CREATE TABLE QuestionType (
Id_QuestionType			TEXT 		PRIMARY KEY
);

CREATE TABLE QuestionTypeLabel (
Id_QuestionType			TEXT,
Id_Language				TEXT,
Name					TEXT 		NOT NULL,
Short_Description		TEXT 		NOT NULL,
Long_Description		TEXT,
PRIMARY KEY (Id_QuestionType, Id_Language),
FOREIGN KEY(Id_QuestionType) REFERENCES QuestionType(Id_QuestionType),
FOREIGN KEY(Id_Language) REFERENCES Language(Id_Language)
);

CREATE TABLE Exercise (
Id_Exercise				INTEGER 	PRIMARY KEY,
Id_QuestionType			INTEGER,
Id_Lesson 				INTEGER		NOT NULL,
Order_Exercise			INTEGER		NOT NULL,
FOREIGN KEY(Id_QuestionType) REFERENCES QuestionType(Id_QuestionType),
FOREIGN KEY(Id_Lesson) REFERENCES Lesson(Id_Lesson),
UNIQUE(Id_Lesson, Order_Exercise)
);

CREATE INDEX exercise_id_lesson on Exercise(Id_Lesson);

CREATE TABLE ExerciseLabel (
Id_Exercise				INTEGER,
Id_Language 			TEXT,
Instruction 			TEXT,
PRIMARY KEY (Id_Exercise, Id_Language),
FOREIGN KEY(Id_Exercise) REFERENCES Exercise(Id_Exercise),
FOREIGN KEY(Id_Language) REFERENCES Language(Id_Language)
);

CREATE TABLE Question (
Id_Question				INTEGER 	PRIMARY KEY,
Id_Exercise				INTEGER 	NOT NULL,
Id_QuestionType			TEXT	 	NOT NULL,
Text_Question 			TEXT,
FOREIGN KEY(Id_Exercise) REFERENCES Exercise(Id_Exercise),
FOREIGN KEY(Id_QuestionType) REFERENCES QuestionType(Id_QuestionType)
);

CREATE TABLE QuestionParam (
Id_QuestionParam		INTEGER 	PRIMARY KEY,
Id_Question				INTEGER 	NOT NULL,
Param					TEXT,
Correct_Answer			INTEGER,
FOREIGN KEY(Id_Question) REFERENCES Question(Id_Question)
);
